@@ -15,8 +15,8 @@
  *
  * This parser implements a "Precedence climbing" algorithm.
  *
- * @see http://www.engr.mun.ca/~theo/Misc/exp_parsing.htm
- * @see http://en.wikipedia.org/wiki/Operator-precedence_parser
+ * @see https://www.engr.mun.ca/~theo/Misc/exp_parsing.htm
+ * @see https://en.wikipedia.org/wiki/Operator-precedence_parser
  *
  * @author Fabien Potencier <fabien@symfony.com>
  *
@@ -81,10 +81,10 @@ class Twig_ExpressionParser
             $class = $operator['class'];
 
             return $this->parsePostfixExpression(new $class($expr, $token->getLine()));
-        } elseif ($token->test(Twig_Token::PUNCTUATION_TYPE, '(')) {
+        } elseif ($token->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(')) {
             $this->parser->getStream()->next();
             $expr = $this->parseExpression();
-            $this->parser->getStream()->expect(Twig_Token::PUNCTUATION_TYPE, ')', 'An opened parenthesis is not properly closed');
+            $this->parser->getStream()->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ')', 'An opened parenthesis is not properly closed');
 
             return $this->parsePostfixExpression($expr);
         }
@@ -94,10 +94,10 @@ class Twig_ExpressionParser
 
     private function parseConditionalExpression($expr)
     {
-        while ($this->parser->getStream()->nextIf(Twig_Token::PUNCTUATION_TYPE, '?')) {
-            if (!$this->parser->getStream()->nextIf(Twig_Token::PUNCTUATION_TYPE, ':')) {
+        while ($this->parser->getStream()->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, '?')) {
+            if (!$this->parser->getStream()->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ':')) {
                 $expr2 = $this->parseExpression();
-                if ($this->parser->getStream()->nextIf(Twig_Token::PUNCTUATION_TYPE, ':')) {
+                if ($this->parser->getStream()->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ':')) {
                     $expr3 = $this->parseExpression();
                 } else {
                     $expr3 = new Twig_Node_Expression_Constant('', $this->parser->getCurrentToken()->getLine());
@@ -115,19 +115,19 @@ class Twig_ExpressionParser
 
     private function isUnary(Twig_Token $token)
     {
-        return $token->test(Twig_Token::OPERATOR_TYPE) && isset($this->unaryOperators[$token->getValue()]);
+        return $token->test(/* Twig_Token::OPERATOR_TYPE */ 8) && isset($this->unaryOperators[$token->getValue()]);
     }
 
     private function isBinary(Twig_Token $token)
     {
-        return $token->test(Twig_Token::OPERATOR_TYPE) && isset($this->binaryOperators[$token->getValue()]);
+        return $token->test(/* Twig_Token::OPERATOR_TYPE */ 8) && isset($this->binaryOperators[$token->getValue()]);
     }
 
     public function parsePrimaryExpression()
     {
         $token = $this->parser->getCurrentToken();
         switch ($token->getType()) {
-            case Twig_Token::NAME_TYPE:
+            case /* Twig_Token::NAME_TYPE */ 5:
                 $this->parser->getStream()->next();
                 switch ($token->getValue()) {
                     case 'true':
@@ -156,17 +156,17 @@ class Twig_ExpressionParser
                 }
                 break;
 
-            case Twig_Token::NUMBER_TYPE:
+            case /* Twig_Token::NUMBER_TYPE */ 6:
                 $this->parser->getStream()->next();
                 $node = new Twig_Node_Expression_Constant($token->getValue(), $token->getLine());
                 break;
 
-            case Twig_Token::STRING_TYPE:
-            case Twig_Token::INTERPOLATION_START_TYPE:
+            case /* Twig_Token::STRING_TYPE */ 7:
+            case /* Twig_Token::INTERPOLATION_START_TYPE */ 10:
                 $node = $this->parseStringExpression();
                 break;
 
-            case Twig_Token::OPERATOR_TYPE:
+            case /* Twig_Token::OPERATOR_TYPE */ 8:
                 if (preg_match(Twig_Lexer::REGEX_NAME, $token->getValue(), $matches) && $matches[0] == $token->getValue()) {
                     // in this context, string operators are variable names
                     $this->parser->getStream()->next();
@@ -191,11 +191,11 @@ class Twig_ExpressionParser
 
                 // no break
             default:
-                if ($token->test(Twig_Token::PUNCTUATION_TYPE, '[')) {
+                if ($token->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '[')) {
                     $node = $this->parseArrayExpression();
-                } elseif ($token->test(Twig_Token::PUNCTUATION_TYPE, '{')) {
+                } elseif ($token->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '{')) {
                     $node = $this->parseHashExpression();
-                } elseif ($token->test(Twig_Token::OPERATOR_TYPE, '=') && ('==' === $this->parser->getStream()->look(-1)->getValue() || '!=' === $this->parser->getStream()->look(-1)->getValue())) {
+                } elseif ($token->test(/* Twig_Token::OPERATOR_TYPE */ 8, '=') && ('==' === $this->parser->getStream()->look(-1)->getValue() || '!=' === $this->parser->getStream()->look(-1)->getValue())) {
                     throw new Twig_Error_Syntax(sprintf('Unexpected operator of value "%s". Did you try to use "===" or "!==" for strict comparison? Use "is same as(value)" instead.', $token->getValue()), $token->getLine(), $this->parser->getStream()->getSourceContext());
                 } else {
                     throw new Twig_Error_Syntax(sprintf('Unexpected token "%s" of value "%s".', Twig_Token::typeToEnglish($token->getType()), $token->getValue()), $token->getLine(), $this->parser->getStream()->getSourceContext());
@@ -213,12 +213,12 @@ class Twig_ExpressionParser
         // a string cannot be followed by another string in a single expression
         $nextCanBeString = true;
         while (true) {
-            if ($nextCanBeString && $token = $stream->nextIf(Twig_Token::STRING_TYPE)) {
+            if ($nextCanBeString && $token = $stream->nextIf(/* Twig_Token::STRING_TYPE */ 7)) {
                 $nodes[] = new Twig_Node_Expression_Constant($token->getValue(), $token->getLine());
                 $nextCanBeString = false;
-            } elseif ($stream->nextIf(Twig_Token::INTERPOLATION_START_TYPE)) {
+            } elseif ($stream->nextIf(/* Twig_Token::INTERPOLATION_START_TYPE */ 10)) {
                 $nodes[] = $this->parseExpression();
-                $stream->expect(Twig_Token::INTERPOLATION_END_TYPE);
+                $stream->expect(/* Twig_Token::INTERPOLATION_END_TYPE */ 11);
                 $nextCanBeString = true;
             } else {
                 break;
@@ -236,16 +236,16 @@ class Twig_ExpressionParser
     public function parseArrayExpression()
     {
         $stream = $this->parser->getStream();
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, '[', 'An array element was expected');
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '[', 'An array element was expected');
 
         $node = new Twig_Node_Expression_Array(array(), $stream->getCurrent()->getLine());
         $first = true;
-        while (!$stream->test(Twig_Token::PUNCTUATION_TYPE, ']')) {
+        while (!$stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']')) {
             if (!$first) {
-                $stream->expect(Twig_Token::PUNCTUATION_TYPE, ',', 'An array element must be followed by a comma');
+                $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',', 'An array element must be followed by a comma');
 
                 // trailing ,?
-                if ($stream->test(Twig_Token::PUNCTUATION_TYPE, ']')) {
+                if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']')) {
                     break;
                 }
             }
@@ -253,7 +253,7 @@ class Twig_ExpressionParser
 
             $node->addElement($this->parseExpression());
         }
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, ']', 'An opened array is not properly closed');
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']', 'An opened array is not properly closed');
 
         return $node;
     }
@@ -261,16 +261,16 @@ class Twig_ExpressionParser
     public function parseHashExpression()
     {
         $stream = $this->parser->getStream();
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, '{', 'A hash element was expected');
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '{', 'A hash element was expected');
 
         $node = new Twig_Node_Expression_Array(array(), $stream->getCurrent()->getLine());
         $first = true;
-        while (!$stream->test(Twig_Token::PUNCTUATION_TYPE, '}')) {
+        while (!$stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '}')) {
             if (!$first) {
-                $stream->expect(Twig_Token::PUNCTUATION_TYPE, ',', 'A hash value must be followed by a comma');
+                $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',', 'A hash value must be followed by a comma');
 
                 // trailing ,?
-                if ($stream->test(Twig_Token::PUNCTUATION_TYPE, '}')) {
+                if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '}')) {
                     break;
                 }
             }
@@ -282,9 +282,9 @@ class Twig_ExpressionParser
             //  * a string -- 'a'
             //  * a name, which is equivalent to a string -- a
             //  * an expression, which must be enclosed in parentheses -- (1 + 2)
-            if (($token = $stream->nextIf(Twig_Token::STRING_TYPE)) || ($token = $stream->nextIf(Twig_Token::NAME_TYPE)) || $token = $stream->nextIf(Twig_Token::NUMBER_TYPE)) {
+            if (($token = $stream->nextIf(/* Twig_Token::STRING_TYPE */ 7)) || ($token = $stream->nextIf(/* Twig_Token::NAME_TYPE */ 5)) || $token = $stream->nextIf(/* Twig_Token::NUMBER_TYPE */ 6)) {
                 $key = new Twig_Node_Expression_Constant($token->getValue(), $token->getLine());
-            } elseif ($stream->test(Twig_Token::PUNCTUATION_TYPE, '(')) {
+            } elseif ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(')) {
                 $key = $this->parseExpression();
             } else {
                 $current = $stream->getCurrent();
@@ -292,12 +292,12 @@ class Twig_ExpressionParser
                 throw new Twig_Error_Syntax(sprintf('A hash key must be a quoted string, a number, a name, or an expression enclosed in parentheses (unexpected token "%s" of value "%s".', Twig_Token::typeToEnglish($current->getType()), $current->getValue()), $current->getLine(), $stream->getSourceContext());
             }
 
-            $stream->expect(Twig_Token::PUNCTUATION_TYPE, ':', 'A hash key must be followed by a colon (:)');
+            $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ':', 'A hash key must be followed by a colon (:)');
             $value = $this->parseExpression();
 
             $node->addElement($value, $key);
         }
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, '}', 'An opened hash is not properly closed');
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '}', 'An opened hash is not properly closed');
 
         return $node;
     }
@@ -306,7 +306,7 @@ class Twig_ExpressionParser
     {
         while (true) {
             $token = $this->parser->getCurrentToken();
-            if (Twig_Token::PUNCTUATION_TYPE == $token->getType()) {
+            if (/* Twig_Token::PUNCTUATION_TYPE */ 9 == $token->getType()) {
                 if ('.' == $token->getValue() || '[' == $token->getValue()) {
                     $node = $this->parseSubscriptExpression($node);
                 } elseif ('|' == $token->getValue()) {
@@ -380,15 +380,15 @@ class Twig_ExpressionParser
         if ('.' == $token->getValue()) {
             $token = $stream->next();
             if (
-                Twig_Token::NAME_TYPE == $token->getType()
+                /* Twig_Token::NAME_TYPE */ 5 == $token->getType()
                 ||
-                Twig_Token::NUMBER_TYPE == $token->getType()
+                /* Twig_Token::NUMBER_TYPE */ 6 == $token->getType()
                 ||
-                (Twig_Token::OPERATOR_TYPE == $token->getType() && preg_match(Twig_Lexer::REGEX_NAME, $token->getValue()))
+                (/* Twig_Token::OPERATOR_TYPE */ 8 == $token->getType() && preg_match(Twig_Lexer::REGEX_NAME, $token->getValue()))
             ) {
                 $arg = new Twig_Node_Expression_Constant($token->getValue(), $lineno);
 
-                if ($stream->test(Twig_Token::PUNCTUATION_TYPE, '(')) {
+                if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(')) {
                     $type = Twig_Template::METHOD_CALL;
                     foreach ($this->parseArguments() as $n) {
                         $arguments->addElement($n);
@@ -415,19 +415,19 @@ class Twig_ExpressionParser
 
             // slice?
             $slice = false;
-            if ($stream->test(Twig_Token::PUNCTUATION_TYPE, ':')) {
+            if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ':')) {
                 $slice = true;
                 $arg = new Twig_Node_Expression_Constant(0, $token->getLine());
             } else {
                 $arg = $this->parseExpression();
             }
 
-            if ($stream->nextIf(Twig_Token::PUNCTUATION_TYPE, ':')) {
+            if ($stream->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ':')) {
                 $slice = true;
             }
 
             if ($slice) {
-                if ($stream->test(Twig_Token::PUNCTUATION_TYPE, ']')) {
+                if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']')) {
                     $length = new Twig_Node_Expression_Constant(null, $token->getLine());
                 } else {
                     $length = $this->parseExpression();
@@ -437,12 +437,12 @@ class Twig_ExpressionParser
                 $arguments = new Twig_Node(array($arg, $length));
                 $filter = new $class($node, new Twig_Node_Expression_Constant('slice', $token->getLine()), $arguments, $token->getLine());
 
-                $stream->expect(Twig_Token::PUNCTUATION_TYPE, ']');
+                $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']');
 
                 return $filter;
             }
 
-            $stream->expect(Twig_Token::PUNCTUATION_TYPE, ']');
+            $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ']');
         }
 
         return new Twig_Node_Expression_GetAttr($node, $arg, $arguments, $type, $lineno);
@@ -458,10 +458,10 @@ class Twig_ExpressionParser
     public function parseFilterExpressionRaw($node, $tag = null)
     {
         while (true) {
-            $token = $this->parser->getStream()->expect(Twig_Token::NAME_TYPE);
+            $token = $this->parser->getStream()->expect(/* Twig_Token::NAME_TYPE */ 5);
 
             $name = new Twig_Node_Expression_Constant($token->getValue(), $token->getLine());
-            if (!$this->parser->getStream()->test(Twig_Token::PUNCTUATION_TYPE, '(')) {
+            if (!$this->parser->getStream()->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(')) {
                 $arguments = new Twig_Node();
             } else {
                 $arguments = $this->parseArguments(true);
@@ -471,7 +471,7 @@ class Twig_ExpressionParser
 
             $node = new $class($node, $name, $arguments, $token->getLine(), $tag);
 
-            if (!$this->parser->getStream()->test(Twig_Token::PUNCTUATION_TYPE, '|')) {
+            if (!$this->parser->getStream()->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '|')) {
                 break;
             }
 
@@ -496,21 +496,21 @@ class Twig_ExpressionParser
         $args = array();
         $stream = $this->parser->getStream();
 
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, '(', 'A list of arguments must begin with an opening parenthesis');
-        while (!$stream->test(Twig_Token::PUNCTUATION_TYPE, ')')) {
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(', 'A list of arguments must begin with an opening parenthesis');
+        while (!$stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, ')')) {
             if (!empty($args)) {
-                $stream->expect(Twig_Token::PUNCTUATION_TYPE, ',', 'Arguments must be separated by a comma');
+                $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',', 'Arguments must be separated by a comma');
             }
 
             if ($definition) {
-                $token = $stream->expect(Twig_Token::NAME_TYPE, null, 'An argument must be a name');
+                $token = $stream->expect(/* Twig_Token::NAME_TYPE */ 5, null, 'An argument must be a name');
                 $value = new Twig_Node_Expression_Name($token->getValue(), $this->parser->getCurrentToken()->getLine());
             } else {
                 $value = $this->parseExpression();
             }
 
             $name = null;
-            if ($namedArguments && $token = $stream->nextIf(Twig_Token::OPERATOR_TYPE, '=')) {
+            if ($namedArguments && $token = $stream->nextIf(/* Twig_Token::OPERATOR_TYPE */ 8, '=')) {
                 if (!$value instanceof Twig_Node_Expression_Name) {
                     throw new Twig_Error_Syntax(sprintf('A parameter name must be a string, "%s" given.', get_class($value)), $token->getLine(), $stream->getSourceContext());
                 }
@@ -541,7 +541,7 @@ class Twig_ExpressionParser
                 }
             }
         }
-        $stream->expect(Twig_Token::PUNCTUATION_TYPE, ')', 'A list of arguments must be closed by a parenthesis');
+        $stream->expect(/* Twig_Token::PUNCTUATION_TYPE */ 9, ')', 'A list of arguments must be closed by a parenthesis');
 
         return new Twig_Node($args);
     }
@@ -551,14 +551,14 @@ class Twig_ExpressionParser
         $stream = $this->parser->getStream();
         $targets = array();
         while (true) {
-            $token = $stream->expect(Twig_Token::NAME_TYPE, null, 'Only variables can be assigned to');
+            $token = $stream->expect(/* Twig_Token::NAME_TYPE */ 5, null, 'Only variables can be assigned to');
             $value = $token->getValue();
             if (in_array(strtolower($value), array('true', 'false', 'none', 'null'))) {
                 throw new Twig_Error_Syntax(sprintf('You cannot assign a value to "%s".', $value), $token->getLine(), $stream->getSourceContext());
             }
             $targets[] = new Twig_Node_Expression_AssignName($value, $token->getLine());
 
-            if (!$stream->nextIf(Twig_Token::PUNCTUATION_TYPE, ',')) {
+            if (!$stream->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',')) {
                 break;
             }
         }
@@ -571,7 +571,7 @@ class Twig_ExpressionParser
         $targets = array();
         while (true) {
             $targets[] = $this->parseExpression();
-            if (!$this->parser->getStream()->nextIf(Twig_Token::PUNCTUATION_TYPE, ',')) {
+            if (!$this->parser->getStream()->nextIf(/* Twig_Token::PUNCTUATION_TYPE */ 9, ',')) {
                 break;
             }
         }
@@ -591,7 +591,7 @@ class Twig_ExpressionParser
 
         $class = $this->getTestNodeClass($test);
         $arguments = null;
-        if ($stream->test(Twig_Token::PUNCTUATION_TYPE, '(')) {
+        if ($stream->test(/* Twig_Token::PUNCTUATION_TYPE */ 9, '(')) {
             $arguments = $this->parser->getExpressionParser()->parseArguments(true);
         }
 
@@ -601,13 +601,13 @@ class Twig_ExpressionParser
     private function getTest($line)
     {
         $stream = $this->parser->getStream();
-        $name = $stream->expect(Twig_Token::NAME_TYPE)->getValue();
+        $name = $stream->expect(/* Twig_Token::NAME_TYPE */ 5)->getValue();
 
         if ($test = $this->env->getTest($name)) {
             return array($name, $test);
         }
 
-        if ($stream->test(Twig_Token::NAME_TYPE)) {
+        if ($stream->test(/* Twig_Token::NAME_TYPE */ 5)) {
             // try 2-words tests
             $name = $name.' '.$this->parser->getCurrentToken()->getValue();
 
